DateAddOptions

Struct DateAddOptions 

#[non_exhaustive]
pub struct DateAddOptions { pub overflow: Option<Overflow>, }
Options for adding a duration to a date.

🚧 This code is considered unstable; it may change at any time, in breaking or non-breaking ways, including in SemVer minor releases. Do not use this type unless you are prepared for things to occasionally break.

Graduation tracking issue: issue #3964.

Enabled with the unstable Cargo feature.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
overflow: Option<Overflow>

How to behave with out-of-bounds fields during arithmetic.

Defaults to Overflow::Constrain.

Examples

use icu::calendar::options::DateAddOptions;
use icu::calendar::options::Overflow;
use icu::calendar::types::DateDuration;
use icu::calendar::Date;

// There is a day 31 in October but not in November.
let d1 = Date::try_new_iso(2025, 10, 31).unwrap();
let duration = DateDuration::for_months(1);

let options_default = DateAddOptions::default();
assert_eq!(
    d1.try_added_with_options(duration, options_default)
        .unwrap(),
    Date::try_new_iso(2025, 11, 30).unwrap()
);

let mut options_reject = options_default;
options_reject.overflow = Some(Overflow::Reject);
assert!(d1.try_added_with_options(duration, options_reject).is_err());

let mut options_constrain = options_default;
options_constrain.overflow = Some(Overflow::Constrain);
assert_eq!(
    d1.try_added_with_options(duration, options_constrain)
        .unwrap(),
    Date::try_new_iso(2025, 11, 30).unwrap()
);