#[non_exhaustive]pub struct DateDifferenceOptions {
pub largest_unit: Option<DateDurationUnit>,
}Expand description
Options for taking the difference between two dates.
🚧 This code is considered unstable; it may change at any time, in breaking or non-breaking ways,
including in SemVer minor releases. Do not use this type unless you are prepared for things to occasionally break.
Graduation tracking issue: issue #3964.
✨ Enabled with the unstable Cargo feature.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.largest_unit: Option<DateDurationUnit>Which date field to allow as the largest in a duration when taking the difference.
When choosing Months or Years, the resulting DateDuration might not be
associative or commutative in subsequent arithmetic operations, and it might require
Overflow::Constrain in addition.
Examples
use icu::calendar::options::DateDifferenceOptions;
use icu::calendar::types::DateDuration;
use icu::calendar::types::DateDurationUnit;
use icu::calendar::Date;
let d1 = Date::try_new_iso(2025, 3, 31).unwrap();
let d2 = Date::try_new_iso(2026, 5, 15).unwrap();
let options_default = DateDifferenceOptions::default();
assert_eq!(
d1.try_until_with_options(&d2, options_default).unwrap(),
DateDuration::for_days(410)
);
let mut options_days = options_default;
options_days.largest_unit = Some(DateDurationUnit::Days);
assert_eq!(
d1.try_until_with_options(&d2, options_default).unwrap(),
DateDuration::for_days(410)
);
let mut options_weeks = options_default;
options_weeks.largest_unit = Some(DateDurationUnit::Weeks);
assert_eq!(
d1.try_until_with_options(&d2, options_weeks).unwrap(),
DateDuration {
weeks: 58,
days: 4,
..Default::default()
}
);
let mut options_months = options_default;
options_months.largest_unit = Some(DateDurationUnit::Months);
assert_eq!(
d1.try_until_with_options(&d2, options_months).unwrap(),
DateDuration {
months: 13,
days: 15,
..Default::default()
}
);
let mut options_years = options_default;
options_years.largest_unit = Some(DateDurationUnit::Years);
assert_eq!(
d1.try_until_with_options(&d2, options_years).unwrap(),
DateDuration {
years: 1,
months: 1,
days: 15,
..Default::default()
}
);Trait Implementations
Sourceimpl Clone for DateDifferenceOptions
impl Clone for DateDifferenceOptions
Sourcefn clone(&self) -> DateDifferenceOptions
fn clone(&self) -> DateDifferenceOptions
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DateDifferenceOptions
impl Debug for DateDifferenceOptions
Sourceimpl Default for DateDifferenceOptions
impl Default for DateDifferenceOptions
Sourcefn default() -> DateDifferenceOptions
fn default() -> DateDifferenceOptions
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for DateDifferenceOptions
impl PartialEq for DateDifferenceOptions
Sourcefn eq(&self, other: &DateDifferenceOptions) -> bool
fn eq(&self, other: &DateDifferenceOptions) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for DateDifferenceOptions
impl StructuralPartialEq for DateDifferenceOptions